#ifndef _widget_config_utility_h
#define _widget_config_utility_h

/*
 *	subtitleeditor -- a tool to create or edit subtitle
 *
 *	http://home.gna.org/subtitleeditor/
 *	https://gna.org/projects/subtitleeditor/
 *
 *	Copyright @ 2005-2009, kitone
 *
 *	This program is free software; you can redistribute it and/or modify
 *	it under the terms of the GNU General Public License as published by
 *	the Free Software Foundation; either version 3 of the License, or
 *	(at your option) any later version.
 *
 *	This program is distributed in the hope that it will be useful,
 *	but WITHOUT ANY WARRANTY; without even the implied warranty of
 *	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *	GNU General Public License for more details.
 *
 *	You should have received a copy of the GNU General Public License
 *	along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

#include <gtkmm.h>

/*
 *
 */
namespace widget_config
{

	/*
	 *
	 */
	void connect(Gtk::Widget *widget, const Glib::ustring &group, const Glib::ustring &key);

	/*
	 *
	 */
	void read_config(Gtk::Widget *widget, const Glib::ustring &group, const Glib::ustring &key);

	/*
	 *
	 */
	void read_config_and_connect(
													Gtk::Widget *widget, 
													const Glib::ustring &group, 
													const Glib::ustring &key);

}//namespace widget_config

#endif//_widget_config_utility_h
